==> apache-hop-2.1.0-src.tar.gz: apache-hop-2.1.0/plugins/transforms/edi2xml/src/test/java/org/apache/hop/pipeline/transforms/edi2xml/Edi2XmlMetaTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.pipeline.transforms.edi2xml;

import org.apache.hop.core.exception.HopException;
import org.apache.hop.junit.rules.RestoreHopEngineEnvironment;
import org.apache.hop.pipeline.transforms.loadsave.LoadSaveTester;
import org.junit.ClassRule;
import org.junit.Test;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class Edi2XmlMetaTest {
  @ClassRule public static RestoreHopEngineEnvironment env = new RestoreHopEngineEnvironment();

  @Test
  public void testTransformMeta() throws HopException {
    List<String> attributes = Arrays.asList("inputfield", "outputfield");

    Map<String, String> getterMap = new HashMap<>();
    getterMap.put("inputfield", "getInputField");
    getterMap.put("outputfield", "getOutputField");

    Map<String, String> setterMap = new HashMap<>();
    setterMap.put("inputfield", "setInputField");
    setterMap.put("outputfield", "setOutputField");

    LoadSaveTester loadSaveTester =
        new LoadSaveTester(Edi2XmlMeta.class, attributes, getterMap, setterMap);
    loadSaveTester.testSerialization();
  }
}

==> apache-hop-2.7.0-src.tar.gz: apache-hop-2.7.0/plugins/transforms/edi2xml/src/test/java/org/apache/hop/pipeline/transforms/edi2xml/Edi2XmlMetaTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.pipeline.transforms.edi2xml;

import org.apache.hop.core.exception.HopException;
import org.apache.hop.core.util.Assert;
import org.apache.hop.junit.rules.RestoreHopEngineEnvironment;
import org.apache.hop.pipeline.transform.TransformSerializationTestUtil;
import org.apache.hop.pipeline.transforms.loadsave.LoadSaveTester;
import org.junit.ClassRule;
import org.junit.Test;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class Edi2XmlMetaTest {
  @Test
  public void testSerialization() throws Exception {
    Edi2XmlMeta meta = TransformSerializationTestUtil.testSerialization(
            "/edi-to-xml-transform.xml", Edi2XmlMeta.class);

    Assert.assertNotNull(meta.getInputField());
    Assert.assertNotNull(meta.getOutputField());

    org.junit.Assert.assertEquals(meta.getInputField(), "edi");
    org.junit.Assert.assertEquals(meta.getOutputField(), "xml");
  }
}
